pub struct FeatureFusion { /* private fields */ }Expand description
Feature fusion module
Combines GNN embeddings, min-cut features, and boundary features into a unified representation for error prediction.
Implementations
Sourceimpl FeatureFusion
impl FeatureFusion
Sourcepub fn new(config: FusionConfig) -> Result<Self>
pub fn new(config: FusionConfig) -> Result<Self>
Create a new feature fusion module
Sourcepub fn fuse_simple(
&self,
gnn_features: &Array2<f32>,
mincut_features: &Array2<f32>,
) -> Result<Array2<f32>>
pub fn fuse_simple( &self, gnn_features: &Array2<f32>, mincut_features: &Array2<f32>, ) -> Result<Array2<f32>>
Sourcepub fn fuse(
&self,
gnn_features: &Array2<f32>,
mincut_features: &Array2<f32>,
boundary_features: &Array2<f32>,
confidences: Option<&[f32]>,
) -> Result<Array2<f32>>
pub fn fuse( &self, gnn_features: &Array2<f32>, mincut_features: &Array2<f32>, boundary_features: &Array2<f32>, confidences: Option<&[f32]>, ) -> Result<Array2<f32>>
Fuse features from multiple sources
Arguments
gnn_features- GNN embeddings (num_nodes, gnn_dim)mincut_features- MinCut features (num_nodes, mincut_dim)boundary_features- Boundary features (num_nodes, 8)confidences- Optional confidence scores for adaptive weighting
Returns
Fused features (num_nodes, output_dim)
Sourcepub fn fuse_all(
&self,
gnn_embeddings: &Array2<f32>,
adjacency: &HashMap<usize, Vec<usize>>,
edge_weights: &HashMap<(usize, usize), f32>,
positions: &[(f32, f32)],
grid_size: usize,
) -> Result<Array2<f32>>
pub fn fuse_all( &self, gnn_embeddings: &Array2<f32>, adjacency: &HashMap<usize, Vec<usize>>, edge_weights: &HashMap<(usize, usize), f32>, positions: &[(f32, f32)], grid_size: usize, ) -> Result<Array2<f32>>
Convenience method to compute all features and fuse them
Arguments
gnn_embeddings- GNN node embeddingsadjacency- Graph adjacency listedge_weights- Edge weights for min-cutpositions- Node positionsgrid_size- Grid size for boundary computation
Sourcepub fn config(&self) -> &FusionConfig
pub fn config(&self) -> &FusionConfig
Get configuration
Sourcepub fn output_dim(&self) -> usize
pub fn output_dim(&self) -> usize
Get output dimension